@@ -19,6 +19,7 @@
 */
 
 
+#include <ctype.h>
 #include <stdlib.h>
 #include <string.h>
 #include <search.h>
@@ -837,12 +838,18 @@ do {                                                                 \
 				char *s = val;
 				int slen = strlen(s);
 				int left = alen;
+				int info_len = 0;
+
+				if (lt_sh(cfg, args_string_pointer_length)) {
+					info_len = snprintf(argbuf, left, "(%p, %zu) ", s, strlen(s));
+					left -= info_len;
+				}
 
 				if ((slen + 2) > left) {
-					snprintf(argbuf, left, "\"%s", s);
+					snprintf(argbuf + info_len, left, "\"%s", s);
 					strncpy(argbuf + left - sizeof("...\"") + 1, "...\"", sizeof("...\""));
 				} else {
-					strcpy(argbuf, "\"");
+					strcpy(argbuf + info_len, "\"");
 					strcat(argbuf, s);
 					strcat(argbuf, "\"");
 				}
@@ -850,7 +857,7 @@ do {                                                                 \
 				len = snprintf(argbuf, alen, "NULL");
 		} else {
 
-			if (*((char*) pval) <= ' ')
+			if (!isprint(*((char*) pval)))
 				len = snprintf(argbuf, alen, "0x%02x",
 						*((unsigned char*) pval));
 			else
